@@ -77,7 +77,7 @@ metacity_theme_apply(const gchar *theme, const gchar *font)
     {
         gchar *gsettings_cmd = NULL;
 
-        /* for metacity <= 3.12 */
+        /* for GNOME3 */
         gsettings_cmd = g_strdup_printf("gsettings set org.gnome.desktop.wm.preferences theme '%s'", theme);
         g_spawn_command_line_async (gsettings_cmd, NULL);
         g_free (gsettings_cmd);
@@ -90,6 +90,11 @@ metacity_theme_apply(const gchar *theme, const gchar *font)
         gsettings_cmd = g_strdup_printf("gsettings set org.gnome.metacity theme '%s'", theme);
         g_spawn_command_line_async (gsettings_cmd, NULL);
         g_free (gsettings_cmd);
+
+        /* for metacity >= 3.20 */
+        gsettings_cmd = g_strdup_printf("gsettings set org.gnome.metacity.theme name '%s'", theme);
+        g_spawn_command_line_async (gsettings_cmd, NULL);
+        g_free (gsettings_cmd);
     }
 }
 
