@@ -71,18 +71,12 @@ capplet_help (GtkWindow *parent, char const *section)
 {
 	GError *error = NULL;
 	char *uri;
-	GdkScreen *screen;
 
 	g_return_if_fail (section != NULL);
 
-	if (!parent)
-		screen = gdk_screen_get_default ();
-	else
-		screen = gtk_widget_get_screen (GTK_WIDGET (parent));
-
 	uri = g_strdup_printf ("help:mate-user-guide/%s", section);
 
-	if (!gtk_show_uri (screen, uri, gtk_get_current_event_time (), &error)) {
+	if (!gtk_show_uri_on_window (parent , uri, gtk_get_current_event_time (), &error)) {
 		capplet_error_dialog (
 			parent,
 			_("There was an error displaying help: %s"),
@@ -176,6 +170,66 @@ capplet_file_delete_recursive (GFile *file, GError **error)
 		return g_file_delete (file, NULL, error);
 }
 
+gboolean
+capplet_dialog_page_scroll_event_cb (GtkWidget *widget, GdkEventScroll *event, GtkWindow *window)
+{
+    GtkNotebook *notebook = GTK_NOTEBOOK (widget);
+    GtkWidget *child, *event_widget, *action_widget;
+
+    child = gtk_notebook_get_nth_page (notebook, gtk_notebook_get_current_page (notebook));
+    if (child == NULL)
+        return FALSE;
+
+    event_widget = gtk_get_event_widget ((GdkEvent *) event);
+
+    /* Ignore scroll events from the content of the page */
+    if (event_widget == NULL ||
+        event_widget == child ||
+        gtk_widget_is_ancestor (event_widget, child))
+        return FALSE;
+
+    /* And also from the action widgets */
+    action_widget = gtk_notebook_get_action_widget (notebook, GTK_PACK_START);
+    if (event_widget == action_widget ||
+        (action_widget != NULL && gtk_widget_is_ancestor (event_widget, action_widget)))
+        return FALSE;
+    action_widget = gtk_notebook_get_action_widget (notebook, GTK_PACK_END);
+    if (event_widget == action_widget ||
+        (action_widget != NULL && gtk_widget_is_ancestor (event_widget, action_widget)))
+        return FALSE;
+
+    switch (event->direction) {
+    case GDK_SCROLL_RIGHT:
+    case GDK_SCROLL_DOWN:
+        gtk_notebook_next_page (notebook);
+        break;
+    case GDK_SCROLL_LEFT:
+    case GDK_SCROLL_UP:
+        gtk_notebook_prev_page (notebook);
+        break;
+    case GDK_SCROLL_SMOOTH:
+        switch (gtk_notebook_get_tab_pos (notebook)) {
+            case GTK_POS_LEFT:
+            case GTK_POS_RIGHT:
+                if (event->delta_y > 0)
+                    gtk_notebook_next_page (notebook);
+                else if (event->delta_y < 0)
+                    gtk_notebook_prev_page (notebook);
+                break;
+            case GTK_POS_TOP:
+            case GTK_POS_BOTTOM:
+                if (event->delta_x > 0)
+                    gtk_notebook_next_page (notebook);
+                else if (event->delta_x < 0)
+                    gtk_notebook_prev_page (notebook);
+                break;
+            }
+        break;
+    }
+
+    return TRUE;
+}
+
 void
 capplet_init (GOptionContext *context,
 	      int *argc,
