@@ -36,6 +36,8 @@
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 
+#include "capplet-util.h"
+
 typedef struct App App;
 typedef struct GrabInfo GrabInfo;
 
@@ -58,7 +60,7 @@ struct App
     GtkWidget	   *panel_checkbox;
     GtkWidget	   *clone_checkbox;
     GtkWidget	   *show_icon_checkbox;
-    GtkWidget      *primary_button;    
+    GtkWidget      *primary_button;
 
     /* We store the event timestamp when the Apply button is clicked */
     GtkWidget      *apply_button;
@@ -1628,7 +1630,7 @@ get_display_name (App *app,
      * translation could be "Pantallas en Espejo", *not* "Espejar Pantallas".
      */
         text = g_strdup_printf (_("Mirror Screens"));
-    } 
+    }
     else {
         text = g_strdup_printf ("<b>%s</b>\n<small>%s</small>", mate_rr_output_info_get_display_name (output), mate_rr_output_info_get_name (output));
     }
@@ -2276,32 +2278,6 @@ dialog_map_event_cb (GtkWidget *widget, GdkEventAny *event, gpointer data)
     return FALSE;
 }
 
-static void
-hide_help_button (App *app)
-{
-    GtkWidget *action_area;
-    GList *children;
-    GList *l;
-
-    action_area = gtk_dialog_get_action_area (GTK_DIALOG (app->dialog));
-    children = gtk_container_get_children (GTK_CONTAINER (action_area));
-
-    for (l = children; l; l = l->next)
-    {
-	GtkWidget *child;
-	int response;
-
-	child = GTK_WIDGET (l->data);
-
-	response = gtk_dialog_get_response_for_widget (GTK_DIALOG (app->dialog), child);
-	if (response == GTK_RESPONSE_HELP)
-	{
-	    gtk_widget_hide (child);
-	    return;
-	}
-    }
-}
-
 static void
 apply_button_clicked_cb (GtkButton *button, gpointer data)
 {
@@ -2396,18 +2372,13 @@ _gtk_builder_get_widget (GtkBuilder *builder, const gchar *name)
 static void
 run_application (App *app)
 {
-#ifndef UIDIR
-#define UIDIR "."
-#endif
-#define UI_FILE UIDIR "/display-capplet.ui"
     GtkBuilder *builder;
     GtkWidget *align;
-    GError *error;
+    GError *error = NULL;
 
-    error = NULL;
     builder = gtk_builder_new ();
 
-    if (gtk_builder_add_from_file (builder, UI_FILE, &error) == 0)
+    if (gtk_builder_add_from_resource (builder, "/org/mate/mcc/display/display-capplet.ui", &error) == 0)
     {
 	g_warning ("Could not parse UI definition: %s", error->message);
 	g_error_free (error);
@@ -2508,9 +2479,6 @@ run_application (App *app)
 
     gtk_container_add (GTK_CONTAINER (align), app->area);
 
-    /* Until we have help to show, we'll just hide the Help button */
-    hide_help_button (app);
-
     app->apply_button = _gtk_builder_get_widget (builder, "apply_button");
     g_signal_connect (app->apply_button, "clicked",
 		      G_CALLBACK (apply_button_clicked_cb), app);
@@ -2532,9 +2500,15 @@ restart:
 	break;
 
     case GTK_RESPONSE_HELP:
-#if 0
-	g_debug ("Help");
-#endif
+        gtk_show_uri_on_window (GTK_DIALOG (app->dialog),
+                                "help:mate-user-guide/goscustdesk-70",
+                                gtk_get_current_event_time (),
+                                &error);
+        if (error)
+        {
+            error_message (app, _("Could not open help content"), error->message);
+            g_error_free (error);
+        }
 	goto restart;
 	break;
 
@@ -2559,11 +2533,7 @@ main (int argc, char **argv)
 {
     App *app;
 
-    bindtextdomain (GETTEXT_PACKAGE, MATELOCALEDIR);
-    bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-    textdomain (GETTEXT_PACKAGE);
-
-    gtk_init (&argc, &argv);
+    capplet_init (NULL, &argc, &argv);
 
     app = g_new0 (App, 1);
 
