@@ -80,8 +80,6 @@ enum {
 #define SOCKS_PROXY_HOST_KEY      "host"
 #define SOCKS_PROXY_PORT_KEY      "port"
 
-#define MATECC_GNP_UI_FILE (MATECC_UI_DIR "/mate-network-properties.ui")
-
 static GtkWidget *details_dialog = NULL;
 static GSList *ignore_hosts = NULL;
 static GtkTreeModel *model = NULL;
@@ -276,8 +274,8 @@ cb_http_details_button_clicked (GtkWidget *button,
 	}
 
 	builder = gtk_builder_new ();
-	if (gtk_builder_add_objects_from_file (builder, MATECC_GNP_UI_FILE,
-					       builder_widgets, &error) == 0) {
+	if (gtk_builder_add_objects_from_resource (builder, "/org/mate/mcc/network/mate-network-properties.ui",
+					           builder_widgets, &error) == 0) {
 		g_warning ("Could not load details dialog: %s", error->message);
 		g_error_free (error);
 		g_object_unref (builder);
@@ -461,15 +459,11 @@ main (int argc, char **argv)
 				    "delete_button_img", NULL};
 	GtkWidget   *widget;
 
-	bindtextdomain (GETTEXT_PACKAGE, MATELOCALEDIR);
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-	textdomain (GETTEXT_PACKAGE);
-
-	gtk_init (&argc, &argv);
+	capplet_init (NULL, &argc, &argv);
 
 	builder = gtk_builder_new ();
-	if (gtk_builder_add_objects_from_file (builder, MATECC_GNP_UI_FILE,
-					       builder_widgets, &error) == 0) {
+	if (gtk_builder_add_objects_from_resource (builder, "/org/mate/mcc/network/mate-network-properties.ui",
+					           builder_widgets, &error) == 0) {
 		g_warning ("Could not load main dialog: %s",
 			   error->message);
 		g_error_free (error);
@@ -485,6 +479,13 @@ main (int argc, char **argv)
 
 	setup_dialog (builder);
 	widget = _gtk_builder_get_widget (builder, "network_dialog");
+
+        GtkNotebook* nb = GTK_NOTEBOOK (_gtk_builder_get_widget (builder, "notebook1"));
+        gtk_widget_add_events (GTK_WIDGET (nb), GDK_SCROLL_MASK);
+        g_signal_connect (GTK_WIDGET (nb), "scroll-event",
+                          G_CALLBACK (capplet_dialog_page_scroll_event_cb),
+                          GTK_WINDOW (widget));
+
 	capplet_set_icon (widget, "network-server");
 	gtk_widget_show_all (widget);
 	gtk_main ();
