@@ -75,8 +75,6 @@ typedef struct {
 	GFileMonitor            *gtk_store_monitor;
 } BookmarkAgentPrivate;
 
-#define PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOOKMARK_AGENT_TYPE, BookmarkAgentPrivate))
-
 enum {
 	PROP_0,
 	PROP_ITEMS,
@@ -118,6 +116,12 @@ static gint recent_item_mru_comp_func (gconstpointer a, gconstpointer b);
 
 static gchar *find_package_data_file (const gchar *filename);
 
+static gint BookmarkAgent_private_offset;
+
+static inline gpointer bookmark_agent_get_instance_private (BookmarkAgent *this)
+{
+	return (G_STRUCT_MEMBER_P (this, BookmarkAgent_private_offset));
+}
 
 GType
 bookmark_agent_get_type ()
@@ -138,6 +142,7 @@ bookmark_agent_get_type ()
 
 		g_define_type_id = g_type_register_static (
 			G_TYPE_OBJECT, "BookmarkAgent", & info, 0);
+		G_ADD_PRIVATE (BookmarkAgent);
 	}
 
 	return g_define_type_id;
@@ -162,13 +167,14 @@ bookmark_agent_get_instance (BookmarkStoreType type)
 gboolean
 bookmark_agent_has_item (BookmarkAgent *this, const gchar *uri)
 {
-	return g_bookmark_file_has_item (PRIVATE (this)->store, uri);
+	BookmarkAgentPrivate *priv = bookmark_agent_get_instance_private (this);
+	return g_bookmark_file_has_item (priv->store, uri);
 }
 
 void
 bookmark_agent_add_item (BookmarkAgent *this, const BookmarkItem *item)
 {
-	BookmarkAgentPrivate *priv = PRIVATE (this);
+	BookmarkAgentPrivate *priv = bookmark_agent_get_instance_private (this);
 
 	if (! item)
 		return;
@@ -195,26 +201,25 @@ bookmark_agent_add_item (BookmarkAgent *this, const BookmarkItem *item)
 void
 bookmark_agent_move_item (BookmarkAgent *this, const gchar *uri, const gchar *uri_new)
 {
-	BookmarkAgentPrivate *priv = PRIVATE (this);
+	BookmarkAgentPrivate *priv = bookmark_agent_get_instance_private (this);
 
 	GError *error = NULL;
 
 	if (! TYPE_IS_RECENT (priv->type))
 		return;
 
-	gtk_recent_manager_move_item (
-		gtk_recent_manager_get_default (), uri, uri_new, & error);
-
-	if (error)
-		libslab_handle_g_error (
-			& error, "%s: unable to update %s with renamed file, [%s] -> [%s].",
-			G_STRFUNC, priv->store_path, uri, uri_new);
+	gtk_recent_manager_move_item (gtk_recent_manager_get_default (), uri, uri_new, &error);
+	if (error) {
+		g_warning ("Unable to update %s with renamed file, [%s] -> [%s]: %s",
+		           priv->store_path, uri, uri_new, error->message);
+		g_error_free (error);
+	}
 }
 
 void
 bookmark_agent_purge_items (BookmarkAgent *this)
 {
-	BookmarkAgentPrivate *priv = PRIVATE (this);
+	BookmarkAgentPrivate *priv = bookmark_agent_get_instance_private (this);
 
 	GError *error = NULL;
 
@@ -222,16 +227,16 @@ bookmark_agent_purge_items (BookmarkAgent *this)
 	gsize   uris_len;
 	gint    i;
 	g_return_if_fail (priv->user_modifiable);
-		
+
 	uris = g_bookmark_file_get_uris (priv->store, &uris_len);
 	if (TYPE_IS_RECENT (priv->type)) {
 		for (i = 0; i < uris_len; i++) {
-			gtk_recent_manager_remove_item (gtk_recent_manager_get_default (), uris [i], & error);
-
-			if (error)
-				libslab_handle_g_error (
-					& error, "%s: unable to remove [%s] from %s.",
-					G_STRFUNC, priv->store_path, uris [i]);
+			gtk_recent_manager_remove_item (gtk_recent_manager_get_default (), uris [i], &error);
+			if (error) {
+				g_warning ("Unable to remove [%s] from %s: %s",
+				           priv->store_path, uris [i], error->message);
+				g_error_free (error);
+			}
 		}
 	} else {
 		for (i = 0; i < uris_len; i++) {
@@ -245,8 +250,7 @@ bookmark_agent_purge_items (BookmarkAgent *this)
 void
 bookmark_agent_remove_item (BookmarkAgent *this, const gchar *uri)
 {
-        BookmarkAgentPrivate *priv = PRIVATE (this);
-
+        BookmarkAgentPrivate *priv = bookmark_agent_get_instance_private (this);
         gint rank;
 
         GError *error = NULL;
@@ -262,13 +266,11 @@ bookmark_agent_remove_item (BookmarkAgent *this, const gchar *uri)
 		return;
 
 	if (TYPE_IS_RECENT (priv->type)) {
-		gtk_recent_manager_remove_item (
-			gtk_recent_manager_get_default (), uri, & error);
-
-		if (error)
-			libslab_handle_g_error (
-				& error, "%s: unable to remove [%s] from %s.",
-				G_STRFUNC, priv->store_path, uri);
+		gtk_recent_manager_remove_item (gtk_recent_manager_get_default (), uri, &error);
+		if (error) {
+			g_warning ("Unable to remove [%s] from %s: %s", priv->store_path, uri, error->message);
+			g_error_free (error);
+		}
 	}
 	else {
 		rank = get_rank (this, uri);
@@ -277,7 +279,7 @@ bookmark_agent_remove_item (BookmarkAgent *this, const gchar *uri)
 
 		if (rank >= 0) {
 			uris = g_bookmark_file_get_uris (priv->store, NULL);
-				 
+
 			for (i =  0; uris && uris [i]; ++i) {
 				rank_i = get_rank (this, uris [i]);
 
@@ -295,7 +297,7 @@ bookmark_agent_remove_item (BookmarkAgent *this, const gchar *uri)
 void
 bookmark_agent_reorder_items (BookmarkAgent *this, const gchar **uris)
 {
-	BookmarkAgentPrivate *priv = PRIVATE (this);
+	BookmarkAgentPrivate *priv = bookmark_agent_get_instance_private (this);
 
 	gint i;
 
@@ -311,7 +313,7 @@ bookmark_agent_reorder_items (BookmarkAgent *this, const gchar **uris)
 static GList *
 make_items_from_bookmark_file (BookmarkAgent *this, GBookmarkFile *store)
 {
-	BookmarkAgentPrivate *priv = PRIVATE (this);
+	BookmarkAgentPrivate *priv = bookmark_agent_get_instance_private (this);
 	gchar **uris;
 	gint i;
 	GList *items_ordered;
@@ -359,7 +361,7 @@ bookmark_agent_update_from_bookmark_file (BookmarkAgent *this, GBookmarkFile *st
 
 	g_return_if_fail (IS_BOOKMARK_AGENT (this));
 
-	priv = PRIVATE (this);
+	priv = bookmark_agent_get_instance_private (this);
 
 	items_ordered = make_items_from_bookmark_file (this, store);
 
@@ -414,6 +416,8 @@ bookmark_agent_class_init (BookmarkAgentClass *this_class)
 	GParamSpec *items_pspec;
 	GParamSpec *status_pspec;
 
+	if (BookmarkAgent_private_offset != 0)
+		g_type_class_adjust_private_offset (this_class, &BookmarkAgent_private_offset);
 
 	g_obj_class->get_property = get_property;
 	g_obj_class->set_property = set_property;
@@ -432,15 +436,13 @@ bookmark_agent_class_init (BookmarkAgentClass *this_class)
 	g_object_class_install_property (g_obj_class, PROP_ITEMS,  items_pspec);
 	g_object_class_install_property (g_obj_class, PROP_STATUS, status_pspec);
 
-	g_type_class_add_private (this_class, sizeof (BookmarkAgentPrivate));
-
 	bookmark_agent_parent_class = g_type_class_peek_parent (this_class);
 }
 
 static void
 bookmark_agent_init (BookmarkAgent *this)
 {
-	BookmarkAgentPrivate *priv = PRIVATE (this);
+	BookmarkAgentPrivate *priv = bookmark_agent_get_instance_private (this);
 
 	priv->type                = -1;
 
@@ -477,7 +479,7 @@ bookmark_agent_new (BookmarkStoreType type)
 	GFile *gtk_store_file;
 
 	this = g_object_new (BOOKMARK_AGENT_TYPE, NULL);
-	priv = PRIVATE (this);
+	priv = bookmark_agent_get_instance_private (this);
 
 	priv->type  = type;
 	priv->store = g_bookmark_file_new ();
@@ -564,7 +566,7 @@ static void
 get_property (GObject *g_obj, guint prop_id, GValue *value, GParamSpec *pspec)
 {
 	BookmarkAgent        *this = BOOKMARK_AGENT (g_obj);
-	BookmarkAgentPrivate *priv = PRIVATE        (this);
+	BookmarkAgentPrivate *priv = bookmark_agent_get_instance_private (this);
 
 
 	switch (prop_id) {
@@ -588,7 +590,7 @@ static void
 finalize (GObject *g_obj)
 {
 	BookmarkAgent *this = BOOKMARK_AGENT (g_obj);
-	BookmarkAgentPrivate *priv = PRIVATE (g_obj);
+	BookmarkAgentPrivate *priv = bookmark_agent_get_instance_private (this);
 
 	gint i;
 
@@ -627,7 +629,7 @@ finalize (GObject *g_obj)
 static void
 update_agent (BookmarkAgent *this)
 {
-	BookmarkAgentPrivate *priv = PRIVATE (this);
+	BookmarkAgentPrivate *priv = bookmark_agent_get_instance_private (this);
 
 	if (priv->update_path)
 		priv->update_path (this);
@@ -641,7 +643,7 @@ update_agent (BookmarkAgent *this)
 static void
 update_items (BookmarkAgent *this)
 {
-	BookmarkAgentPrivate *priv = PRIVATE (this);
+	BookmarkAgentPrivate *priv = bookmark_agent_get_instance_private (this);
 
 	gchar    **uris            = NULL;
 	gchar    **uris_ordered    = NULL;
@@ -742,7 +744,7 @@ update_items (BookmarkAgent *this)
 static void
 save_store (BookmarkAgent *this)
 {
-	BookmarkAgentPrivate *priv = PRIVATE (this);
+	BookmarkAgentPrivate *priv = bookmark_agent_get_instance_private (this);
 
 	gchar *dir;
 
@@ -763,7 +765,7 @@ save_store (BookmarkAgent *this)
 static gint
 get_rank (BookmarkAgent *this, const gchar *uri)
 {
-	BookmarkAgentPrivate *priv = PRIVATE (this);
+	BookmarkAgentPrivate *priv = bookmark_agent_get_instance_private (this);
 
 	gchar **groups;
 	gint    rank;
@@ -796,7 +798,7 @@ get_rank (BookmarkAgent *this, const gchar *uri)
 static void
 set_rank (BookmarkAgent *this, const gchar *uri, gint rank)
 {
-	BookmarkAgentPrivate *priv = PRIVATE (this);
+	BookmarkAgentPrivate *priv = bookmark_agent_get_instance_private (this);
 
 	gchar **groups;
 	gchar  *group;
@@ -823,7 +825,7 @@ set_rank (BookmarkAgent *this, const gchar *uri, gint rank)
 static void
 load_xbel_store (BookmarkAgent *this)
 {
-	BookmarkAgentPrivate *priv = PRIVATE (this);
+	BookmarkAgentPrivate *priv = bookmark_agent_get_instance_private (this);
 
 	gchar **uris = NULL;
 
@@ -842,10 +844,12 @@ load_xbel_store (BookmarkAgent *this)
 		g_bookmark_file_free (priv->store);
 		priv->store = g_bookmark_file_new ();
 
-		libslab_handle_g_error (
-			& error, "%s: couldn't load bookmark file [%s]\n",
-			G_STRFUNC, priv->store_path ? priv->store_path : "NULL");
-
+		if (error) {
+			g_debug ("Couldn't load bookmark file [%s]: %s", priv->store_path, error->message);
+			g_error_free (error);
+		} else {
+			g_debug ("Couldn't load bookmark file [NULL]");
+		}
 		return;
 	}
 
@@ -860,12 +864,12 @@ load_xbel_store (BookmarkAgent *this)
 static void
 load_places_store (BookmarkAgent *this)
 {
-	BookmarkAgentPrivate *priv = PRIVATE (this);
+	BookmarkAgentPrivate *priv = bookmark_agent_get_instance_private (this);
 
 	gchar **uris;
 	gchar **groups;
 	gchar **bookmarks = NULL;
-	
+
 	gchar  *buf, *label, *uri;
 
 	gint i, j, bookmark_len;
@@ -928,10 +932,10 @@ find_package_data_file (const gchar *filename)
 
 
 	dirs = g_get_system_data_dirs ();
-	
+
 	for (i = 0; ! path && dirs && dirs [i]; ++i) {
 		path = g_build_filename (dirs [i], PACKAGE, filename, NULL);
-		
+
 		if (! g_file_test (path, G_FILE_TEST_EXISTS)) {
 			g_free (path);
 			path = NULL;
@@ -944,7 +948,7 @@ find_package_data_file (const gchar *filename)
 static void
 update_user_spec_path (BookmarkAgent *this)
 {
-	BookmarkAgentPrivate *priv = PRIVATE (this);
+	BookmarkAgentPrivate *priv = bookmark_agent_get_instance_private (this);
 
 	gboolean  use_user_path;
 	gchar    *path = NULL;
@@ -967,7 +971,7 @@ update_user_spec_path (BookmarkAgent *this)
 		status = BOOKMARK_STORE_DEFAULT_ONLY;
 	else
 		status = BOOKMARK_STORE_ABSENT;
-	
+
 	if (priv->status != status) {
 		priv->status = status;
 		g_object_notify (G_OBJECT (this), BOOKMARK_AGENT_STORE_STATUS_PROP);
@@ -1023,20 +1027,25 @@ update_user_spec_path (BookmarkAgent *this)
 static void
 save_xbel_store (BookmarkAgent *this)
 {
-	BookmarkAgentPrivate *priv = PRIVATE (this);
+	BookmarkAgentPrivate *priv = bookmark_agent_get_instance_private (this);
 
 	GError *error = NULL;
 
+	if (g_bookmark_file_to_file (priv->store, priv->store_path, &error))
+		return;
 
-	if (! g_bookmark_file_to_file (priv->store, priv->store_path, & error))
-		libslab_handle_g_error (
-			& error, "%s: couldn't save bookmark file [%s]\n", G_STRFUNC, priv->store_path);
+	if (error) {
+		g_warning ("Couldn't save bookmark file [%s]: %s", priv->store_path, error->message);
+		g_error_free (error);
+	} else {
+		g_warning ("Couldn't save bookmark file [%s]", priv->store_path);
+	}
 }
 
 static void
 create_app_item (BookmarkAgent *this, const gchar *uri)
 {
-	BookmarkAgentPrivate *priv = PRIVATE (this);
+	BookmarkAgentPrivate *priv = bookmark_agent_get_instance_private (this);
 
 	MateDesktopItem *ditem;
 	gchar *uri_new = NULL;
@@ -1060,7 +1069,7 @@ create_app_item (BookmarkAgent *this, const gchar *uri)
 static void
 create_doc_item (BookmarkAgent *this, const gchar *uri)
 {
-	BookmarkAgentPrivate *priv = PRIVATE (this);
+	BookmarkAgentPrivate *priv = bookmark_agent_get_instance_private (this);
 
 	gchar *uri_new = NULL;
 
@@ -1119,7 +1128,7 @@ create_doc_item (BookmarkAgent *this, const gchar *uri)
 static void
 create_dir_item (BookmarkAgent *this, const gchar *uri)
 {
-	BookmarkAgentPrivate *priv = PRIVATE (this);
+	BookmarkAgentPrivate *priv = bookmark_agent_get_instance_private (this);
 
 	gchar *uri_new = NULL;
 	gchar *path = NULL;
@@ -1193,7 +1202,7 @@ create_dir_item (BookmarkAgent *this, const gchar *uri)
 
 	if (name)
 		g_bookmark_file_set_title (priv->store, uri, name);
-	
+
 	if (uri_new && libslab_strcmp (uri, uri_new))
 		g_bookmark_file_move_item (priv->store, uri, uri_new, NULL);
 
